@@ -14,7 +14,7 @@ Example
 ...             TEXT = 'baz'
 ...             class_ = 'note trailing underscore'
 ...
->>> print(to_string(html(), indent='    '))
+>>> print(to_string(html, indent='    '))
 <!DOCTYPE html>
 <html>
     <body>
@@ -30,4 +30,4 @@ from .serialize import to_string  # noqa: F401
 
 __all__ = ('E', 'to_string')
 
-__version__ = '0.2.2'
+__version__ = '0.3.1'
